# Release notes
All notable changes to this project will be documented in this file.
This project adheres to [Semantic Versioning](http://semver.org/).


## 0.1.2
- packaging fixup: extractMetaData script: fixed error in resource management
- packaging fixup: removed config.json from pkg

## 0.1.0
- Initial version of HappyFeat